@@ -8,7 +8,7 @@ def run_simulation(file_name :str, scenarios = [], return_profiles : bool = Fals
 
     :param file_name: name of the model file
     :type file_name: str
-    :param scenarios: String representations of the scenarios to be run. If empty, runs all scenarios in the model, defaults to []
+    :param scenarios: String representations of the scenarios to be run. To run scenarios which are already in the model we can pass in the scenario names. If empty, runs all scenarios in the model, defaults to []. 
     :type scenarios: list, optional
     :param return_profiles: Return the profiles as well as the endpoints, defaults to False
     :type return_profiles: bool, optional
@@ -33,7 +33,7 @@ def run_verification(file_name : str, scenarios = [], verification_type : int =
 
     :param file_name: name of the model file
     :type file_name: str
-    :param scenarios: String representations of the scenarios to be run. If empty, runs all scenarios in the model, defaults to []
+    :param scenarios: Names of the scenarios to be run. If empty, runs all scenarios in the model, defaults to []
     :type scenarios: list, optional
     :param verification_type: Verification type. 1 for full report, 2 for residuals, 3 for SSQs, defaults to 1
     :type verification_type: int, optional
